@@ -75,6 +75,7 @@ class Location:
         time_zone: Optional[str] = None,
         kind: Optional[str] = None,
         vertical_datum_info: Optional[Union[str, dict[str, Any]]] = None,
+        **other_info: Optional[Any],
     ):
         """
         Initializes a Location object
@@ -89,6 +90,7 @@ class Location:
             elevation_unit (Optional[str]): The unit of elevation of the location. Defaults to None.
             vertical_datum (Optional[str]): The native vertical datum of the specified elevation. Defaults to None.
             vertical_datum_info (Optional[Union[str, dict[str,Any]]]): The vertical datum info for the location. Overrides `elevation`, `elevation_unit`, and `vertical_datum` parameters, if also specified. Defaults to None.
+            other_info (Optional[dict[str,Any]]): Optional dictionary of other location info. Is accessible via `other_info` property
         """
         if not isinstance(name, str):
             raise TypeError(f"Expected str for 'name', got {name.__class__.__name__}")
@@ -106,6 +108,7 @@ class Location:
         self._vertical_datum_info: Optional[
             hec.parameter.ElevParameter._VerticalDatumInfo
         ] = None
+        self._other_info = other_info
         if elevation and elevation_unit:
             self._elevation = UnitQuantity(elevation, elevation_unit)
         if vertical_datum is not None:
@@ -393,6 +396,16 @@ class Location:
                     )
             self._office = v
 
+    @property
+    def other_info(self) -> Optional[dict[str, Any]]:
+        """
+        Dictionary of information provided to initializer.
+
+        Operations:
+            Read-Only
+        """
+        return self._other_info
+
     @property
     def subname(self) -> Optional[str]:
         """
@@ -480,7 +493,7 @@ class Location:
         if value is None:
             self._vertical_datum_info = None
         elif isinstance(value, hec.parameter.ElevParameter._VerticalDatumInfo):
-            self._vertical_datum_info = value.clone()
+            self._vertical_datum_info = value.copy()
         elif isinstance(value, dict):
             s = re.sub(r"\b(True|False)\b", lambda m: m.group(0).lower(), str(value))
             self._vertical_datum_info = hec.parameter.ElevParameter._VerticalDatumInfo(
@@ -497,6 +510,12 @@ class Location:
 
     @property
     def vertical_datum_json(self) -> Optional[str]:
+        """
+        The vertical datum info of the location, if any, as a JSON object
+
+        Operations:
+            Read-Only
+        """
         vdi = self._vertical_datum_info
         if vdi:
             buf = StringIO()
@@ -506,7 +525,7 @@ class Location:
                     f'"elevation":{vdi.elevation.magnitude},"unit":"{vdi.elevation.specified_unit}",'
                 )
             else:
-                buf.write(f'"elevation":null,"unit":"null",')
+                buf.write(f'"elevation":null,"unit":null,')
             buf.write(f'"native-datum":"{vdi.native_datum}",')
             if vdi.navd88_offset or vdi.ngvd29_offset:
                 buf.write('"offsets":[')
@@ -530,6 +549,12 @@ class Location:
 
     @property
     def vertical_datum_xml(self) -> Optional[str]:
+        """
+        The vertical datum info of the location, if any, as an XML instance
+
+        Operations:
+            Read-Only
+        """
         vdi = self._vertical_datum_info
         if vdi:
             lines = str(self._vertical_datum_info).split("\n")
